==> jc-1.4.0.tar.gz: gnu/xml/util/SAXNullTransformerFactory__24NullHandler.h <==
// class gnu.xml.util.SAXNullTransformerFactory$NullHandler

// class file dependencies
// @dep_class c2c3ed4310a669e3 gnu_xml_pipeline_EventFilter
// @dep_class 20bb32a724a0baf gnu_xml_util_SAXNullTransformerFactory__24NullHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_EventFilter

#include "gnu/xml/pipeline/EventFilter.h"

#ifndef _JC_gnu_xml_util_SAXNullTransformerFactory__24NullHandler_H_
#define _JC_gnu_xml_util_SAXNullTransformerFactory__24NullHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_transform_Result$object;
struct _jc_javax_xml_transform_Transformer$object;

// Typedefs
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object;

typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vmethods	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vmethods;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtable	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtable;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtype	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtype;

// Constructors
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method$_init$33d94dd34a79472e(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *, struct _jc_javax_xml_transform_Transformer$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *);
extern struct _jc_javax_xml_transform_Transformer$object *_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method$getTransformer$5e1e9148f1619f75(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *);
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method$setResult$eda6b6a87a19b573(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *, struct _jc_object *);
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method$setSystemId$2edffdaf6427879d(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method_info$getTransformer$5e1e9148f1619f75;
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method_info$setResult$eda6b6a87a19b573;
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method_info$setSystemId$2edffdaf6427879d;

// Virtual methods structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vmethods {
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *);
	struct _jc_javax_xml_transform_Transformer$object	*(*getTransformer$5e1e9148f1619f75)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *);
	void	(*setResult$eda6b6a87a19b573)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *, struct _jc_object *);
	void	(*setSystemId$2edffdaf6427879d)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_EventFilter$vmethods	gnu_xml_pipeline_EventFilter;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vmethods	gnu_xml_util_SAXNullTransformerFactory__24NullHandler;
};

// Vtype
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_refs {
	struct _jc_java_lang_String$object	*systemId;
	struct _jc_javax_xml_transform_Transformer$object	*transformer;
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$refs {
    _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_refs	gnu_xml_util_SAXNullTransformerFactory__24NullHandler;
    _jc_gnu_xml_pipeline_EventFilter$sub_refs	gnu_xml_pipeline_EventFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_EventFilter$sub_nonrefs	gnu_xml_pipeline_EventFilter;
    _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_nonrefs	gnu_xml_util_SAXNullTransformerFactory__24NullHandler;
};

// Object instance structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object {
	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtype	*vtype;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtype _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_SAXNullTransformerFactory__24NullHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$class_object;

#endif	/* _JC_gnu_xml_util_SAXNullTransformerFactory__24NullHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/util/SAXNullTransformerFactory__24NullHandler.h <==
// class gnu.xml.util.SAXNullTransformerFactory$NullHandler

// class file dependencies
// @dep_class c2c3ed4310a669e3 gnu_xml_pipeline_EventFilter
// @dep_class 20bb32a724a0baf gnu_xml_util_SAXNullTransformerFactory__24NullHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_EventFilter

#include "gnu/xml/pipeline/EventFilter.h"

#ifndef _JC_gnu_xml_util_SAXNullTransformerFactory__24NullHandler_H_
#define _JC_gnu_xml_util_SAXNullTransformerFactory__24NullHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_transform_Result$object;
struct _jc_javax_xml_transform_Transformer$object;

// Typedefs
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object;

typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vmethods	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vmethods;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtable	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtable;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtype	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtype;

// Constructors
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method$_init$33d94dd34a79472e(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *, struct _jc_javax_xml_transform_Transformer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_xml_transform_Transformer$object *_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method$getTransformer$5e1e9148f1619f75(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method$setResult$eda6b6a87a19b573(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method$setSystemId$2edffdaf6427879d(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method_info$getTransformer$5e1e9148f1619f75;
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method_info$setResult$eda6b6a87a19b573;
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$method_info$setSystemId$2edffdaf6427879d;

// Virtual methods structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vmethods {
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *) _JC_JCNI_ATTR;
	struct _jc_javax_xml_transform_Transformer$object	*(*getTransformer$5e1e9148f1619f75)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *) _JC_JCNI_ATTR;
	void	(*setResult$eda6b6a87a19b573)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setSystemId$2edffdaf6427879d)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_EventFilter$vmethods	gnu_xml_pipeline_EventFilter;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vmethods	gnu_xml_util_SAXNullTransformerFactory__24NullHandler;
};

// Vtype
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_refs {
	struct _jc_java_lang_String$object	*systemId;
	struct _jc_javax_xml_transform_Transformer$object	*transformer;
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$refs {
    _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_refs	gnu_xml_util_SAXNullTransformerFactory__24NullHandler;
    _jc_gnu_xml_pipeline_EventFilter$sub_refs	gnu_xml_pipeline_EventFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_EventFilter$sub_nonrefs	gnu_xml_pipeline_EventFilter;
    _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$sub_nonrefs	gnu_xml_util_SAXNullTransformerFactory__24NullHandler;
};

// Object instance structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$object {
	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtype	*vtype;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$vtype _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_SAXNullTransformerFactory__24NullHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_SAXNullTransformerFactory__24NullHandler$class_object;

#endif	/* _JC_gnu_xml_util_SAXNullTransformerFactory__24NullHandler_H_ */
